==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/appwizard/kdevappwizard.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=project-development-new-template
Exec=blubb
Comment=Application Wizard
Comment[bg]=Съветник на приложение
Comment[bs]=Čarobnjak aplikacija
Comment[ca]=Assistent d'aplicació
Comment[ca@valencia]=Assistent d'aplicació
Comment[cs]=Průvodce aplikací
Comment[da]=Applikationsguide
Comment[de]=Anwendungsassistent
Comment[el]=Οδηγός εφαρμογής
Comment[en_GB]=Application Wizard
Comment[es]=Asistente de aplicaciones
Comment[et]=Rakenduse nõustaja
Comment[fi]=Opastettu sovelluksen luonti
Comment[fr]=Assistant d'applications
Comment[ga]=Treoraí Feidhmchláir
Comment[gl]=Asistente para programas
Comment[hu]=Alkalmazás varázsló
Comment[it]=Procedura guidata applicazione
Comment[ja]=アプリケーションウィザード
Comment[kk]=Қолданба шебері
Comment[nb]=Programveiviser
Comment[nds]=Programm-Hölper
Comment[nl]=Programma-assistent
Comment[pl]=Asystent programu
Comment[pt]=Assistente de Aplicações
Comment[pt_BR]=Assistente de aplicativo
Comment[ru]=Мастер создания приложений
Comment[sk]=Sprievodca aplikáciou
Comment[sl]=Čarovnik za program
Comment[sv]=Programguide
Comment[tr]=Uygulama Sihirbazı
Comment[ug]=ئەمىلى پروگرامما يېتەكچىسى
Comment[uk]=Майстер створення програм
Comment[x-test]=xxApplication Wizardxx
Comment[zh_CN]=应用程序向导
Comment[zh_TW]=應用程式精靈
Name=New Project Wizard
Name[bg]=Съветник за нов проект
Name[bs]=Čarobnjak novog projekta
Name[ca]=Assistent de projecte nou
Name[ca@valencia]=Assistent de projecte nou
Name[cs]=Průvodce novým projektem
Name[da]=Guide til nyt projekt
Name[de]=Projekt-Assistent
Name[el]=Οδηγός ρύθμισης νέου έργου
Name[en_GB]=New Project Wizard
Name[es]=Asistente de nuevo proyecto
Name[et]=Uue projekti nõustaja
Name[fi]=Uuden projektin opastettu luonti
Name[fr]=Assistant de création de nouveau projet
Name[gl]=Asistente para proxectos novos
Name[hu]=Új projekt varázsló
Name[it]=Procedura guidata nuovo progetto
Name[ja]=新規プロジェクト作成ウィザード
Name[kk]=Жаңа жоба шебері
Name[nb]=Veiviser for nytt prosjekt
Name[nds]=Projekt-Hölper
Name[nl]=Nieuwe projectenassistent
Name[pl]=Asystent nowego projektu
Name[pt]=Assistente de Novos Projectos
Name[pt_BR]=Assistente de novo projeto
Name[ru]=Мастер создания проекта
Name[sk]=Sprievodca novým projektom
Name[sl]=Čarovnik za nov projekt
Name[sv]=Ny projektguide
Name[tr]=Yeni Proje Sihirbazı
Name[ug]=يېڭى قۇرۇلۇش يېتەكچىسى
Name[uk]=Майстер створення проекту
Name[x-test]=xxNew Project Wizardxx
Name[zh_CN]=新工程向导
Name[zh_TW]=新增專案精靈
GenericName=Application Wizard
GenericName[bg]=Съветник на приложение
GenericName[bs]=Čarobnjak aplikacija
GenericName[ca]=Assistent d'aplicació
GenericName[ca@valencia]=Assistent d'aplicació
GenericName[cs]=Průvodce aplikací
GenericName[da]=Applikationsguide
GenericName[de]=Anwendungsassistent
GenericName[el]=Οδηγός εφαρμογής
GenericName[en_GB]=Application Wizard
GenericName[es]=Asistente de aplicaciones
GenericName[et]=Rakenduse nõustaja
GenericName[fi]=Opastettu sovelluksen luonti
GenericName[fr]=Assistant d'applications
GenericName[ga]=Treoraí Feidhmchláir
GenericName[gl]=Asistente para programas
GenericName[hu]=Alkalmazás varázsló
GenericName[it]=Procedura guidata applicazione
GenericName[ja]=アプリケーションウィザード
GenericName[kk]=Қолданба шебері
GenericName[nb]=Programveiviser
GenericName[nds]=Programm-Hölper
GenericName[nl]=Programma-assistent
GenericName[pl]=Asystent programu
GenericName[pt]=Assistente de Aplicações
GenericName[pt_BR]=Assistente de aplicativo
GenericName[ru]=Мастер создания приложений
GenericName[sk]=Sprievodca aplikáciou
GenericName[sl]=Čarovnik za program
GenericName[sv]=Programguide
GenericName[tr]=Uygulama Sihirbazı
GenericName[ug]=ئەمىلى پروگرامما يېتەكچىسى
GenericName[uk]=Майстер створення програм
GenericName[x-test]=xxApplication Wizardxx
GenericName[zh_CN]=应用程序向导
GenericName[zh_TW]=應用程式精靈
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevappwizard
X-KDE-PluginInfo-Name=kdevappwizard
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.ITemplateProvider
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Mode=GUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/appwizard/kdevappwizard.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=project-development-new-template
Exec=blubb
Comment=Application Wizard
Comment[bg]=Съветник на приложение
Comment[bs]=Čarobnjak aplikacija
Comment[ca]=Assistent d'aplicació
Comment[ca@valencia]=Assistent d'aplicació
Comment[cs]=Průvodce aplikací
Comment[da]=Applikationsguide
Comment[de]=Anwendungsassistent
Comment[el]=Οδηγός εφαρμογής
Comment[en_GB]=Application Wizard
Comment[es]=Asistente de aplicaciones
Comment[et]=Rakenduse nõustaja
Comment[fi]=Opastettu sovelluksen luonti
Comment[fr]=Assistant d'applications
Comment[ga]=Treoraí Feidhmchláir
Comment[gl]=Asistente para programas
Comment[hu]=Alkalmazás varázsló
Comment[it]=Procedura guidata applicazione
Comment[ja]=アプリケーションウィザード
Comment[kk]=Қолданба шебері
Comment[nb]=Programveiviser
Comment[nds]=Programm-Hölper
Comment[nl]=Programma-assistent
Comment[pl]=Pomocnik programu
Comment[pt]=Assistente de Aplicações
Comment[pt_BR]=Assistente de aplicativo
Comment[ru]=Мастер создания приложений
Comment[sk]=Sprievodca aplikáciou
Comment[sl]=Čarovnik za program
Comment[sv]=Programguide
Comment[tr]=Uygulama Sihirbazı
Comment[ug]=ئەمىلى پروگرامما يېتەكچىسى
Comment[uk]=Майстер створення програм
Comment[x-test]=xxApplication Wizardxx
Comment[zh_CN]=应用程序向导
Comment[zh_TW]=應用程式精靈
Name=New Project Wizard
Name[bg]=Съветник за нов проект
Name[bs]=Čarobnjak novog projekta
Name[ca]=Assistent de projecte nou
Name[ca@valencia]=Assistent de projecte nou
Name[cs]=Průvodce novým projektem
Name[da]=Guide til nyt projekt
Name[de]=Projekt-Assistent
Name[el]=Οδηγός ρύθμισης νέου έργου
Name[en_GB]=New Project Wizard
Name[es]=Asistente de nuevo proyecto
Name[et]=Uue projekti nõustaja
Name[fi]=Uuden projektin opastettu luonti
Name[fr]=Assistant de création de nouveau projet
Name[gl]=Asistente para proxectos novos
Name[hu]=Új projekt varázsló
Name[it]=Procedura guidata nuovo progetto
Name[ja]=新規プロジェクト作成ウィザード
Name[kk]=Жаңа жоба шебері
Name[nb]=Veiviser for nytt prosjekt
Name[nds]=Projekt-Hölper
Name[nl]=Nieuwe projectenassistent
Name[pl]=Pomocnik nowego projektu
Name[pt]=Assistente de Novos Projectos
Name[pt_BR]=Assistente de novo projeto
Name[ru]=Мастер создания проекта
Name[sk]=Sprievodca novým projektom
Name[sl]=Čarovnik za nov projekt
Name[sv]=Ny projektguide
Name[tr]=Yeni Proje Sihirbazı
Name[ug]=يېڭى قۇرۇلۇش يېتەكچىسى
Name[uk]=Майстер створення проекту
Name[x-test]=xxNew Project Wizardxx
Name[zh_CN]=新工程向导
Name[zh_TW]=新增專案精靈
GenericName=Application Wizard
GenericName[bg]=Съветник на приложение
GenericName[bs]=Čarobnjak aplikacija
GenericName[ca]=Assistent d'aplicació
GenericName[ca@valencia]=Assistent d'aplicació
GenericName[cs]=Průvodce aplikací
GenericName[da]=Applikationsguide
GenericName[de]=Anwendungsassistent
GenericName[el]=Οδηγός εφαρμογής
GenericName[en_GB]=Application Wizard
GenericName[es]=Asistente de aplicaciones
GenericName[et]=Rakenduse nõustaja
GenericName[fi]=Opastettu sovelluksen luonti
GenericName[fr]=Assistant d'applications
GenericName[ga]=Treoraí Feidhmchláir
GenericName[gl]=Asistente para programas
GenericName[hu]=Alkalmazás varázsló
GenericName[it]=Procedura guidata applicazione
GenericName[ja]=アプリケーションウィザード
GenericName[kk]=Қолданба шебері
GenericName[nb]=Programveiviser
GenericName[nds]=Programm-Hölper
GenericName[nl]=Programma-assistent
GenericName[pl]=Pomocnik programu
GenericName[pt]=Assistente de Aplicações
GenericName[pt_BR]=Assistente de aplicativo
GenericName[ru]=Мастер создания приложений
GenericName[sk]=Sprievodca aplikáciou
GenericName[sl]=Čarovnik za program
GenericName[sv]=Programguide
GenericName[tr]=Uygulama Sihirbazı
GenericName[ug]=ئەمىلى پروگرامما يېتەكچىسى
GenericName[uk]=Майстер створення програм
GenericName[x-test]=xxApplication Wizardxx
GenericName[zh_CN]=应用程序向导
GenericName[zh_TW]=應用程式精靈
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevappwizard
X-KDE-PluginInfo-Name=kdevappwizard
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.ITemplateProvider
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Mode=GUI
